==> image_pickers-1.0.4%2B1.tar.gz: ios/Classes/AKGallery/PlayTheVideoVC.m <==
//
//  PlayTheVideoVC.m
//  Chat
//
//  Created by Admin on 2018/9/12.
//  Copyright © 2018年 桥通天下. All rights reserved.
//

#import "PlayTheVideoVC.h"
#import <AVFoundation/AVFoundation.h> //需要导入框架
#import "ZLPhotoActionSheet.h"
#define Frame_rectStatus ([[UIApplication sharedApplication] statusBarFrame].size.height)
#define Frame_rectNav (self.navigationController.navigationBar.frame.size.height)
#define Frame_NavAndStatus (self.navigationController.navigationBar.frame.size.height+[[UIApplication sharedApplication] statusBarFrame].size.height)
#define CXCHeightX   ( ([UIScreen mainScreen].bounds.size.height>=812.00)?([[UIScreen mainScreen] bounds].size.height-34):([[UIScreen mainScreen] bounds].size.height)/1.000)
#define CXCWeight   ( ([[UIScreen mainScreen] bounds].size.width)/1.000)
#define IPHONE_X \ ({BOOL isPhoneX = NO;\ if (@available(iOS 11.0, *)) {\ isPhoneX = [[UIApplication sharedApplication] delegate].window.safeAreaInsets.bottom > 0.0;\ }\ (isPhoneX);})

@interface PlayTheVideoVC ()

@end

@implementation PlayTheVideoVC

- (void)viewDidLoad {
    [super viewDidLoad];
    [self.view setBackgroundColor:[UIColor whiteColor]];
    if ([self respondsToSelector:@selector(setEdgesForExtendedLayout:)]) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
    }
//    //替代导航栏的imageview
//    UIImageView *topImageView = [[UIImageView alloc]init];
//    if(![PlayTheVideoVC isPhoneX]){
//        topImageView.frame = CGRectMake(0, 0, CXCWeight, 64);
//    }else{
//        topImageView.frame = CGRectMake(0, 0, CXCWeight, 84);
//    }
//    topImageView.userInteractionEnabled = YES;
//    topImageView.backgroundColor = [UIColor whiteColor];
//    [self.view addSubview:topImageView];

 

    if(_videoUrl){
        
        AVAsset *_asset;
        if([_videoUrl rangeOfString: @"http"].location == NSNotFound) {
            NSURL *url = [NSURL fileURLWithPath:_videoUrl];
            _asset = [AVURLAsset assetWithURL:url];
        } else {
            _asset = [AVURLAsset URLAssetWithURL:[NSURL URLWithString:[NSString stringWithFormat:@"%@",_videoUrl]] options:nil];
        }
        AVPlayerItem *playerItem = [AVPlayerItem playerItemWithAsset:_asset];
        AVPlayer *player = [AVPlayer playerWithPlayerItem:playerItem];
        AVPlayerLayer *playerLayer = [AVPlayerLayer playerLayerWithPlayer:player];
        playerLayer.frame = CGRectMake(0, 0, CXCWeight, CXCHeightX);

        playerLayer.videoGravity = AVLayerVideoGravityResizeAspect;
        [self.view.layer addSublayer:playerLayer];
        [player play];

    }else{
        
        
        
    }
  
    //添加返回按钮
    UIButton *  returnBtn = [UIButton buttonWithType:UIButtonTypeCustom];
    returnBtn.frame = CGRectMake(0, Frame_rectStatus, Frame_rectNav, Frame_rectNav);
    if(![PlayTheVideoVC isPhoneX]){
        returnBtn.frame = CGRectMake(0, 20, 44, 44);
    }else{
        returnBtn.frame = CGRectMake(0, 40, 44, 44);
    }
    
    [returnBtn setTitleColor:[UIColor blackColor] forState:UIControlStateNormal];
    [returnBtn setImage:[UIImage imageNamed:@"IMG_4343.jpg"] forState:UIControlStateNormal];
    [returnBtn setTitle:@"<" forState:UIControlStateNormal];
    [returnBtn addTarget:self action:@selector(returnBtnAction) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:returnBtn];
   
}
+ (BOOL)isPhoneX {
    BOOL iPhoneX = NO;
    if (UIDevice.currentDevice.userInterfaceIdiom != UIUserInterfaceIdiomPhone) {//判断是否是手机
        return iPhoneX;
    }
    if (@available(iOS 11.0, *)) {
        UIWindow *mainWindow = [[[UIApplication sharedApplication] delegate] window];
        if (mainWindow.safeAreaInsets.bottom > 0.0) {
            iPhoneX = YES;
        }
    }
    return iPhoneX;
    
}
-(void)returnBtnAction{
    
    [self dismissViewControllerAnimated:YES completion:^{
        
    }];
    
}
- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end

==> image_pickers-2.0.0%2B1.tar.gz: ios/Classes/AKGallery/PlayTheVideoVC.m <==
//
//  PlayTheVideoVC.m
//  Chat
//
//  Created by Admin on 2018/9/12.
//  Copyright © 2018年 桥通天下. All rights reserved.
//

#import "PlayTheVideoVC.h"
#import <AVFoundation/AVFoundation.h> //需要导入框架
#if __has_include(<ZLPhotoBrowser_objc/ZLPhotoBrowser.h>)

#import <ZLPhotoBrowser_objc/ZLPhotoBrowser.h>
#else
#import "ZLPhotoBrowser.h"

#endif
#define Frame_rectStatus ([[UIApplication sharedApplication] statusBarFrame].size.height)
#define Frame_rectNav (self.navigationController.navigationBar.frame.size.height)
#define Frame_NavAndStatus (self.navigationController.navigationBar.frame.size.height+[[UIApplication sharedApplication] statusBarFrame].size.height)
#define CXCHeightX   ( ([UIScreen mainScreen].bounds.size.height>=812.00)?([[UIScreen mainScreen] bounds].size.height-34):([[UIScreen mainScreen] bounds].size.height)/1.000)
#define CXCWeight   ( ([[UIScreen mainScreen] bounds].size.width)/1.000)
#define IPHONE_X \ ({BOOL isPhoneX = NO;\ if (@available(iOS 11.0, *)) {\ isPhoneX = [[UIApplication sharedApplication] delegate].window.safeAreaInsets.bottom > 0.0;\ }\ (isPhoneX);})

@interface PlayTheVideoVC ()

@end

@implementation PlayTheVideoVC

- (void)viewDidLoad {
    [super viewDidLoad];
    [self.view setBackgroundColor:[UIColor whiteColor]];
    if ([self respondsToSelector:@selector(setEdgesForExtendedLayout:)]) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
    }
    
    self.view.backgroundColor =[UIColor blackColor];
//    //替代导航栏的imageview
//    UIImageView *topImageView = [[UIImageView alloc]init];
//    if(![PlayTheVideoVC isPhoneX]){
//        topImageView.frame = CGRectMake(0, 0, CXCWeight, 64);
//    }else{
//        topImageView.frame = CGRectMake(0, 0, CXCWeight, 84);
//    }
//    topImageView.userInteractionEnabled = YES;
//    topImageView.backgroundColor = [UIColor whiteColor];
//    [self.view addSubview:topImageView];
    UITapGestureRecognizer * singleTap =[[UITapGestureRecognizer alloc]initWithTarget:self action:@selector(returnBtnAction)];
    singleTap.numberOfTapsRequired=1;
    [self.view addGestureRecognizer:singleTap];

    if(_videoUrl){
        
        AVAsset *_asset;
        if([_videoUrl rangeOfString: @"http"].location == NSNotFound) {
            NSURL *url = [NSURL fileURLWithPath:_videoUrl];
            _asset = [AVURLAsset assetWithURL:url];
        } else {
            _asset = [AVURLAsset URLAssetWithURL:[NSURL URLWithString:[NSString stringWithFormat:@"%@",_videoUrl]] options:nil];
        }
        AVPlayerItem *playerItem = [AVPlayerItem playerItemWithAsset:_asset];
        AVPlayer *player = [AVPlayer playerWithPlayerItem:playerItem];
        AVPlayerLayer *playerLayer = [AVPlayerLayer playerLayerWithPlayer:player];
        playerLayer.frame = CGRectMake(0, 0, CXCWeight, CXCHeightX);

        playerLayer.videoGravity = AVLayerVideoGravityResizeAspect;
        [self.view.layer addSublayer:playerLayer];
        [player play];

    }else{
        
        
        
    }
  
//    //添加返回按钮
//    UIButton *  returnBtn = [UIButton buttonWithType:UIButtonTypeCustom];
//    returnBtn.frame = CGRectMake(0, Frame_rectStatus, Frame_rectNav, Frame_rectNav);
//    if(![PlayTheVideoVC isPhoneX]){
//        returnBtn.frame = CGRectMake(0, 20, 44, 44);
//    }else{
//        returnBtn.frame = CGRectMake(0, 40, 44, 44);
//    }
//    UIImage *image =[[UIImage alloc]init];
//    NSBundle *bundle5 =[NSBundle bundleForClass:[self class]];
//
//
////    NSBundle *bundle2 =[NSBundle bundleForClass:[self class]];
////    NSBundle *bundle3 =[NSBundle mainBundle];
////    NSBundle *bundle =[NSBundle bundleWithPath:[bundle5 pathForResource:@"image" ofType:@"bundle"]];
//
//    if (@available(iOS 13.0, *)) {
//        image =[UIImage imageNamed:@"btn_apply_for" inBundle:bundle5 withConfiguration:nil];
//    } else {
//        // Fallback on earlier versions
//        image =[UIImage imageNamed:@"btn_apply_for" inBundle:bundle5 compatibleWithTraitCollection:nil];
//    }
//    NSArray *array = [NSBundle allFrameworks];
//    NSLog(@"%@",array);
//
//
//
//    [returnBtn setTitleColor:[UIColor blackColor] forState:UIControlStateNormal];
//    returnBtn.backgroundColor =[UIColor whiteColor];
//    [returnBtn setImage:image forState:UIControlStateNormal];
////    [returnBtn setTitle:@"<" forState:UIControlStateNormal];
//    [returnBtn addTarget:self action:@selector(returnBtnAction) forControlEvents:UIControlEventTouchUpInside];
//    [self.view addSubview:returnBtn];
//
}
+ (BOOL)isPhoneX {
    BOOL iPhoneX = NO;
    if (UIDevice.currentDevice.userInterfaceIdiom != UIUserInterfaceIdiomPhone) {//判断是否是手机
        return iPhoneX;
    }
    if (@available(iOS 11.0, *)) {
        UIWindow *mainWindow = [[[UIApplication sharedApplication] delegate] window];
        if (mainWindow.safeAreaInsets.bottom > 0.0) {
            iPhoneX = YES;
        }
    }
    return iPhoneX;
    
}
-(void)returnBtnAction{
    
    [self dismissViewControllerAnimated:YES completion:^{

    }];
    
}
- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
